@@ -996,3 +996,8 @@ if (\Froxlor\Froxlor::isFroxlorVersion('0.10.35.1')) {
 	showUpdateStep("Updating from 0.10.35.1 to 0.10.36", false);
 	\Froxlor\Froxlor::updateToVersion('0.10.36');
 }
+
+if (\Froxlor\Froxlor::isFroxlorVersion('0.10.36')) {
+	showUpdateStep("Updating from 0.10.36 to 0.10.37", false);
+	\Froxlor\Froxlor::updateToVersion('0.10.37');
+}
